Link Control Commands — MAX BLE HCI 0.1.0 documentation

# Link Control Commands

## Disconnect

Terminate an existing connection.

Command | OCF | Command Parameters | Return Parameters
--- | --- | --- | ---
DISCONNECT | 0x0006 | Connection_Handle Reason |

### Parameters

Connection_Handle, size = 2 octets
Value(s) | Parameter Description
--- | ---
0x0000 to 0x0EFF | Indicates which connection is to be disconnected

Reason, size = 1 octet
Value(s) | Parameter Description
--- | ---
0x05 0x13 to 0x15 0x1A 0x29 0x3B | Reason for ending the connection. Available reasons: Authentication Failure (0x5) Other End Terminated Connection (0x13 to 0x15) Unsupported Remote Feature (0x1A) Pairing with Unit Key Not Supported (0x29) Unacceptable Connection Parameters (0x3B)

### Return Parameters

None.

### Event(s) Generated

- COMMAND_STATUS

- DICON_COMPLETE

- LE_META

    - CIS_ESTABLISHED (if issued for CIS before CIS is finished establishing)

## Read Remote Version Information

Obtain version information values from a remote device.

Command | OCF | Command Parameters | Return Parameters
--- | --- | --- | ---
READ_REMOTE_VER_INFO | 0x001D | Connection_Handle |

### Parameters

Connection_Handle, size = 2 octets
Value(s) | Parameter Description
--- | ---
0x0000 to 0x0EFF | Indicates which connection to obtain version info from

### Return Parameters

None.

### Event(s) Generated

- COMMAND_STATUS

- READ_REMOTE_VERSION_INFO_COMPLETE